/**
 *
 */
package de.intevation.gnv.artifactdatabase.client;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Logger;

import de.intevation.gnv.artifactdatabase.client.exception.ArtifactDatabaseClientException;
import de.intevation.gnv.artifactdatabase.objects.ArtifactDescription;
import de.intevation.gnv.artifactdatabase.objects.ArtifactObject;
import de.intevation.gnv.artifactdatabase.objects.DefaultInputParameter;
import de.intevation.gnv.artifactdatabase.objects.InputParameter;
import de.intevation.gnv.util.XSLTransformer;

import junit.framework.TestCase;

/**
 * @author Tim Englich <tim.englich@intevation.de>
 *
 */
public class ArtifactDatabaseClientTestCase extends TestCase {

    /**
     * the logger, used to log exceptions and additonaly information
     */
    private static Logger log = null;
    
    static{
        BasicConfigurator.configure();
        log = Logger.getLogger(DefaultArtifactDatabaseClient.class);
    }
    /**
     * Constructor
     * @param namemessage
     */
    public ArtifactDatabaseClientTestCase(String name) {
        super(name);
    }

    /**
     * @see junit.framework.TestCase#setUp()
     */
    protected void setUp() throws Exception {
        super.setUp();
    }
    
    public void testArtifactDatabaseClient(){
        
        try {
            ArtifactDatabaseClient artifactDatabaseClient = ArtifactDatabaseClientFactory.getInstance().getArtifactDatabaseClient();
            Collection<ArtifactObject> factories = artifactDatabaseClient.getArtifactFactories();
            if (factories != null && !factories.isEmpty()){
                Iterator<ArtifactObject> it = factories.iterator();
                while(it.hasNext()){
                    ArtifactObject aof = it.next();
                    ArtifactObject artifact = artifactDatabaseClient.createNewArtifact(aof);
                    ArtifactDescription ad = artifactDatabaseClient.getCurrentStepDescription(aof, artifact);
                    log.debug("Artifact aktualisert.");
                    XSLTransformer transformer = new XSLTransformer();
                    String transformedUI = transformer.transform(ad.getCurrentUI(), "UTF-8",("src/main/webapp/WEB-INF/config/templates/describe-ui.xsl"));
                    log.debug(transformedUI);
                    
                    Collection<InputParameter> inputParameter = new ArrayList<InputParameter>(1);
                    inputParameter.add(new DefaultInputParameter("product", new String[]{"timeSeries"}));
                    ad = artifactDatabaseClient.doNextStep(aof, artifact, "timeSeries",inputParameter);
                    
                    transformedUI = transformer.transform(ad.getCurrentUI(), "UTF-8",("src/main/webapp/WEB-INF/config/templates/describe-ui.xsl"));
                    log.debug(transformedUI);
                }
            }
            
            
        } catch (ArtifactDatabaseClientException e) {
            log.error(e,e);
            fail();
        }
    }

}
